@@ -14,7 +14,7 @@ def concat_dataframes(*df_list):
     >>> concat_df_obj_list = []
     >>> for index, grouped_list in enumerate(grouped(200, df_obj_list)):
     >>>     j = b.new_python_job(name=f'concat-dataframes_{index}')
-    >>>     j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas:0.1.0')
+    >>>     j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas-batchutils:0.1.5')
     >>>     df = j.call(concat_dataframes, *grouped_list)
     >>>     concat_df_obj_list.append(df)
     """
@@ -34,7 +34,7 @@ def export_dataframes(*df_list):
     Examples
     --------
     >>> j = b.new_python_job(name='export-dataframes-all')
-    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas:0.1.0')
+    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas-batchutils:0.1.5')
     >>> result = j.call(concat_dataframes, *df_obj_list)
     >>> b.write_output(result.as_str(), outfile_path)
     """
@@ -58,7 +58,7 @@ def export_joined_dataframes(df1, key, how='outer', *df_list):
     Examples
     --------
     >>> j = b.new_python_job(name='join-and-export-dataframes-all')
-    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas:0.1.0')
+    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas-batchutils:0.1.5')
     >>> result = j.call(concat_dataframes, df1, key, how='outer', *df_obj_list)
     >>> b.write_output(result.as_str(), outfile_path)
     """
@@ -79,7 +79,7 @@ def export_concat_dataframes(df1, *df_list):
     Examples
     --------
     >>> j = b.new_python_job(name='join-and-export-dataframes-all')
-    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas:0.1.0')
+    >>> j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas-batchutils:0.1.5')
     >>> result = j.call(export_concat_dataframes, df1, *df_obj_list)
     >>> b.write_output(result.as_str(), outfile_path)
     """
